@@ -14,11 +14,10 @@
 open ExtLib
 open Common
 open Debian
+open DoseparseNoRpm
 
 include Util.Logging(struct let label = __FILE__ end) ;;
 
-module Boilerplate = BoilerplateNoRpm
-
 module Options = struct
   open OptParse
   let description = (
@@ -43,19 +42,19 @@ module Options = struct
     "without a source package but there is a source package of same name but "^
     "different version, match this binary package to that source package.") allowsrcmismatch;
 
-  include Boilerplate.InputOptions;;
-  let default = List.filter (fun e -> not (List.mem e ["checkonly";"latest";"fg";"bg"])) Boilerplate.InputOptions.default_options in
-  Boilerplate.InputOptions.add_options ~default options;;
+  include StdOptions.InputOptions;;
+  let default = List.filter (fun e -> not (List.mem e ["checkonly";"latest";"fg";"bg"])) StdOptions.InputOptions.default_options in
+  StdOptions.InputOptions.add_options ~default options;;
 
-  include Boilerplate.DistribOptions;;
-    let default = List.filter (fun e -> not (List.mem e ["deb-ignore-essential"; "inputtype"])) Boilerplate.DistribOptions.default_options in
-  Boilerplate.DistribOptions.add_options ~default options;;
+  include StdOptions.DistribOptions;;
+    let default = List.filter (fun e -> not (List.mem e ["deb-ignore-essential"; "inputtype"])) StdOptions.DistribOptions.default_options in
+  StdOptions.DistribOptions.add_options ~default options;;
 end
 
 let main () =
   let posargs = OptParse.OptParser.parse_argv Options.options in
-  Boilerplate.enable_debug (OptParse.Opt.get Options.verbose);
-  Boilerplate.all_quiet (OptParse.Opt.get Options.quiet);
+  StdDebug.enable_debug (OptParse.Opt.get Options.verbose);
+  StdDebug.all_quiet (OptParse.Opt.get Options.quiet);
 
   let options = Options.set_deb_options () in
   let buildarch = Option.get options.Debian.Debcudf.native in
