@@ -323,7 +323,33 @@ let from_ic universe ic =
 
   let module GB = Graph.Builder.I(G) in
   let module GR = GraphmlReader.Parse(GB)(struct let node = node let edge = edge end) in
-  GR.parse ic
+  (* we want the graph builder to traverse the nodes and edges of the input XML
+   * in a deterministic order. This is so that given the same input graph
+   * (where "same" means that all node and edge attributes are the same but
+   * their order in the XML document may be different) the resulting SrcPkg
+   * and InstSet nodes get assigned the same Unique.uid. This in turn is so
+   * that it is possible to quickly get a stable order of all vertices
+   * between individual runs because many algorithms will sort input
+   * vertex lists and sorting by their Unique.uid is many times faster than
+   * sorting by package name and version comparison.
+   *
+   * So instead of letting all algorithms using this graph sort by package name
+   * and version, we want to be able to allow quick integer based sorts. But
+   * for that the integer assigned to each package name/version must be
+   * the same between different runs even if the order in which nodes and
+   * edges in the input graph should be different.
+   *
+   * We rely on the mandatory "id" attribute of nodes and edges to be the same
+   * between different runs for the same content. We expect only the order
+   * to be different as the order should not matter (both nodes and edges are
+   * sets)
+   * *)
+  let sort l1 l2 =
+    let id1 = List.assoc "id" l1 in
+    let id2 = List.assoc "id" l2 in
+    Pervasives.compare id1 id2
+  in
+  GR.parse ~nodesort:(Some sort) ~edgesort:(Some sort) ic
 ;;
 
 module Graphml (U : sig val univ : Cudf.universe end)  = struct
