@@ -167,7 +167,7 @@ def main(packages_f, sources_f):
                     continue
                 if arch == "all":
                     print("build-dependency %s unsatisfiable due to " +
-                          "arch:all M-A:none" % dep)
+                          "arch:all M-A:no" % dep)
                     continue
                 if dep in binhave or dep in binneeded:
                     print(
